searchData={"items":[{"type":"module","title":"PublicSufx","doc":"Implements the publicsuffix algorithm described at https://publicsuffix.org/list/.","ref":"PublicSufx.html"},{"type":"function","title":"PublicSufx.prevailing_rule/1","doc":"Parses the provided domain and returns the prevailing rule based on the\npublicsuffix.org rules. If no rules match, the prevailing rule is \"*\",\nunless the provided domain has a leading dot, in which case the input is\ninvalid and the function returns `nil`.","ref":"PublicSufx.html#prevailing_rule/1"},{"type":"function","title":"Examples - PublicSufx.prevailing_rule/1","doc":"iex> prevailing_rule(\"foo.bar.com\")\n    \"com\"\n    iex> prevailing_rule(\"co.uk\")\n    \"co.uk\"\n    iex> prevailing_rule(\"foo.ck\")\n    \"*.ck\"\n    iex> prevailing_rule(\"foobar.example\")\n    \"*\"\n    iex> prevailing_rule(\"foo.github.io\")\n    \"github.io\"","ref":"PublicSufx.html#prevailing_rule/1-examples"},{"type":"function","title":"PublicSufx.public_suffix/1","doc":"Extracts the public suffix from the provided domain based on the publicsuffix.org rules.","ref":"PublicSufx.html#public_suffix/1"},{"type":"function","title":"Examples - PublicSufx.public_suffix/1","doc":"iex> public_suffix(\"foo.bar.com\")\n    \"com\"\n    iex> public_suffix(\"foo.github.io\")\n    \"github.io\"","ref":"PublicSufx.html#public_suffix/1-examples"},{"type":"function","title":"PublicSufx.public_suffix?/1","doc":"Returns true if the supplied domain is a public suffix based on the publicsuffix.org rules, false otherwise.","ref":"PublicSufx.html#public_suffix?/1"},{"type":"function","title":"Examples - PublicSufx.public_suffix?/1","doc":"iex> public_suffix?(\"foo.bar.com\")\n    false\n    iex> public_suffix?(\"com\")\n    true\n    iex> public_suffix?(\"foo.github.io\")\n    false\n    iex> public_suffix?(\"github.io\")\n    true","ref":"PublicSufx.html#public_suffix?/1-examples"},{"type":"extras","title":"PublicSufx","doc":"# PublicSufx\n\n[![CI](https://github.com/reisub/public_sufx/actions/workflows/ci.yml/badge.svg)](https://github.com/reisub/public_sufx/actions/workflows/ci.yml)\n[![License](https://img.shields.io/hexpm/l/public_sufx.svg)](https://github.com/reisub/public_sufx/blob/main/LICENSE)\n[![Version](https://img.shields.io/hexpm/v/public_sufx.svg)](https://hex.pm/packages/public_sufx)\n[![Hex Docs](https://img.shields.io/badge/documentation-gray.svg)](https://hexdocs.pm/public_sufx)\n\n`PublicSufx` is an Elixir library to operate on domain names using\nthe public suffix rules provided by https://publicsuffix.org/:\n\n> A \"public suffix\" is one under which Internet users can (or\n> historically could) directly register names. Some examples of public\n> suffixes are `.com`, `.co.uk` and `pvt.k12.ma.us`. The Public Suffix List is\n> a list of all known public suffixes.\n\nThis Elixir library provides a means to get the public suffix from any domain:\n\n```iex\niex(1)> PublicSufx.public_suffix(\"mysite.foo.bar.com\")\n\"com\"\niex(2)> PublicSufx.public_suffix(\"mysite.foo.bar.co.uk\")\n\"co.uk\"\n```\n\n... and a way to check if a domain is a public suffix:\n\n```iex\niex(1)> PublicSufx.public_suffix?(\"mysite.foo.bar.co.uk\")\nfalse\niex(2)> PublicSufx.public_suffix?(\"co.uk\")\ntrue\n```\n\nThe publicsuffix.org data file contains both official ICANN records\nand private records:\n\n> ICANN domains are those delegated by ICANN or part of the IANA root zone database. The authorized registry may express further policies on how they operate the TLD, such as subdivisions within it. Updates to this section can be submitted by anyone, but if they are not an authorized representative of the registry then they will need to back up their claims of error with documentation from the registry's website.\n>\n> PRIVATE domains are amendments submitted by the domain holder, as an expression of how they operate their domain security policy. Updates to this section are only accepted from authorized representatives of the domain registrant. This is so we can be certain they know what they are getting into.","ref":"readme.html"},{"type":"extras","title":"Working with Rules - PublicSufx","doc":"You can also gain access to the prevailing rule for a particular domain:\n\n```iex\niex(1)> PublicSufx.prevailing_rule(\"mysite.foo.bar.com\")\n\"com\"\niex(2)> PublicSufx.prevailing_rule(\"mysite.example\")\n\"*\"\n```","ref":"readme.html#working-with-rules"},{"type":"extras","title":"Installation - PublicSufx","doc":"The package can be installed by adding `public_sufx` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:public_sufx, \"~> 0.6.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - PublicSufx","doc":"`PublicSufx` also bundled with a cached copy of the public suffix list from\npublicsuffix.org and can be configured to download a fresh copy of the list\non compilation by adding this in your `config.exs`:\n\n```elixir\nconfig :public_sufx, download_data_on_compile: true\n```\n\nThere are pros and cons to both approaches; which you choose will depend\non the needs of your project:\n\n* Setting `download_data_on_compile` to `true` will ensure that the\n  rules are always up-to-date (as of the time you last compiled) but\n  could introduce an instability. While we have tried to implement\n  the logic in this library according to the publicsuffix.org spec,\n  one can imagine future rule changes not being handled properly by\n  the existing logic and manifesting itself in a new bug.\n* Setting `download_data_on_compile` to `false` (or not setting it at\n  all) ensures stable, consistent behavior. In the context of your\n  project, you may want compilation to be deterministic. Compilation\n  is also a bit faster when a new copy of the rules is not downloaded.","ref":"readme.html#configuration"},{"type":"extras","title":"Changelog","doc":"# Changelog\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.6.0] - 2025-04-20","ref":"changelog.html"},{"type":"extras","title":"Changed - Changelog","doc":"- `download_data_on_compile` is now false by default, see [reasons](https://github.com/reisub/public_sufx/issues/1)\n- support Elixir 1.14\n- upate cached rules list\n\n## [0.5.0] - 2025-04-09","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Forked `axelson/publicsuffix-elixir`\n- Rewrote parsing and rule storage logic","ref":"changelog.html#changed"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}